@@ -2,7 +2,5 @@ from Products.CMFCore.utils import getToolByName
 
 def uninstall(portal):
     setup_tool = getToolByName(portal, 'portal_setup')
-    setup_tool.setImportContext('profile-plonetheme.cultureCab:uninstall')
-    setup_tool.runAllImportSteps()
-#    setup_tool.setImportContext('profile-CMFPlone:plone')
+    setup_tool.runAllImportStepsFromProfile('profile-plonetheme.cultureCab:uninstall')
     return "Ran all uninstall steps."
