@@ -14,10 +14,11 @@ class GlobalSectionsViewlet(ViewletBase):
         actions = context_state.actions()
         portal_tabs_view = getMultiAdapter((self.context, self.request),
                                            name='portal_tabs_view')
-        self.portal_tabs = portal_tabs_view.topLevelTabs(actions=actions)
+        self.portal_tabs = portal_tabs_view.topLevelTabs()
 
         selectedTabs = self.context.restrictedTraverse('selectedTabs')
         self.selected_tabs = selectedTabs('index_html',
                                           self.context,
                                           self.portal_tabs)
-        self.selected_portal_tab = self.selected_tabs['portal']
\ No newline at end of file
+        self.selected_portal_tab = self.selected_tabs['portal']
+	
